==> org.eclipse.sirius.diagram.ui.source_2.0.0.201410241344.jar: org/eclipse/sirius/diagram/ui/tools/internal/figure/DConnectionLayerEx.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 THALES GLOBAL SERVICES.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.diagram.ui.tools.internal.figure;

import org.eclipse.draw2d.ConnectionRouter;
import org.eclipse.gmf.runtime.draw2d.ui.internal.figures.ConnectionLayerEx;
import org.eclipse.sirius.diagram.ui.tools.internal.routers.DForestRouter;

/**
 * The connection layer for Designer. This layer uses the
 * {@link org.eclipse.sirius.diagram.ui.tools.internal.routers.DTreeRouter}
 * for tree connections.
 * 
 * @author ymortier
 */
public class DConnectionLayerEx extends ConnectionLayerEx {

    /** The tree router to use. */
    private DForestRouter treeRouter;

    /**
     * {@inheritDoc}
     * 
     * @see org.eclipse.gmf.runtime.draw2d.ui.internal.figures.ConnectionLayerEx#getTreeRouter()
     */
    @Override
    public ConnectionRouter getTreeRouter() {
        if (treeRouter == null) {
            treeRouter = new DForestRouter();
        }
        return treeRouter;
    }
    // This code has been disabled as the layouting results were not nice enough
    // for the customer
    // /**
    // * {@inheritDoc}
    // */
    // @Override
    // public ConnectionRouter getObliqueRouter() {
    // return new BorderItemObliqueRouterSpec();
    // }
    //
    // /**
    // * {@inheritDoc}
    // */
    // @Override
    // public ConnectionRouter getRectilinearRouter() {
    // return new BorderItemRectilinearRouterSpec();
    // }

}

==> org.eclipse.sirius.diagram.ui.source_7.4.11.202508120844.jar: org/eclipse/sirius/diagram/ui/tools/internal/figure/DConnectionLayerEx.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2009 THALES GLOBAL SERVICES.
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.diagram.ui.tools.internal.figure;

import org.eclipse.draw2d.ConnectionRouter;
import org.eclipse.gmf.runtime.draw2d.ui.internal.figures.ConnectionLayerEx;
import org.eclipse.sirius.diagram.ui.tools.internal.routers.DForestRouter;
import org.eclipse.sirius.diagram.ui.tools.internal.routers.SiriusRectilinearRouter;

/**
 * The connection layer for Sirius. This layer uses the
 * {@link org.eclipse.sirius.diagram.ui.tools.internal.routers.DTreeRouter} for
 * tree connections and the {@link SiriusRectilinearRouter} for rectilinear
 * connections.
 * 
 * @author ymortier
 */
public class DConnectionLayerEx extends ConnectionLayerEx {

    /** The tree router to use. */
    private DForestRouter treeRouter;

    private ConnectionRouter rectilinearRouter;

    /**
     * {@inheritDoc}
     * 
     * @see org.eclipse.gmf.runtime.draw2d.ui.internal.figures.ConnectionLayerEx#getTreeRouter()
     */
    @Override
    public ConnectionRouter getTreeRouter() {
        if (treeRouter == null) {
            treeRouter = new DForestRouter();
        }
        return treeRouter;
    }

    // This code has been disabled as the layouting results were not nice enough
    // for the customer
    // /**
    // * {@inheritDoc}
    // */
    // @Override
    // public ConnectionRouter getObliqueRouter() {
    // return new BorderItemObliqueRouterSpec();
    // }

    @Override
    public ConnectionRouter getRectilinearRouter() {
        if (rectilinearRouter == null)
            rectilinearRouter = new SiriusRectilinearRouter();

        return rectilinearRouter;
    }

}
